# coding: utf-8

"""
    Battery Data API

    A standard API for accessing battery experiment datasets and metadata  # noqa: E501

    The version of the OpenAPI document: 2.1.20
    Contact: martin.robinson@cs.ox.ac.uk
    Generated by: https://openapi-generator.tech
"""

from galv.paths.experiments_.post import ExperimentsCreate
from galv.paths.experiments_uuid_.delete import ExperimentsDestroy
from galv.paths.experiments_.get import ExperimentsList
from galv.paths.experiments_uuid_.patch import ExperimentsPartialUpdate
from galv.paths.experiments_uuid_.get import ExperimentsRetrieve


class ExperimentsApi(
    ExperimentsCreate,
    ExperimentsDestroy,
    ExperimentsList,
    ExperimentsPartialUpdate,
    ExperimentsRetrieve,
):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """
    pass



from galv.paths.equipment_uuid_.get import ApiForget
from galv.paths.equipment_uuid_.delete import ApiFordelete
from galv.paths.equipment_uuid_.patch import ApiForpatch


class EquipmentUuid(
    ApiForget,
    ApiFordelete,
    ApiForpatch,
):
    pass



# coding: utf-8

"""
    Battery Data API

    A standard API for accessing battery experiment datasets and metadata  # noqa: E501

    The version of the OpenAPI document: 2.1.20
    Contact: martin.robinson@cs.ox.ac.uk
    Generated by: https://openapi-generator.tech
"""

from galv.paths.teams_.post import TeamsCreate
from galv.paths.teams_id_.delete import TeamsDestroy
from galv.paths.teams_.get import TeamsList
from galv.paths.teams_id_.patch import TeamsPartialUpdate
from galv.paths.teams_id_.get import TeamsRetrieve


class TeamsApi(
    TeamsCreate,
    TeamsDestroy,
    TeamsList,
    TeamsPartialUpdate,
    TeamsRetrieve,
):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """
    pass



# coding: utf-8

"""
    Battery Data API

    A standard API for accessing battery experiment datasets and metadata  # noqa: E501

    The version of the OpenAPI document: 2.1.20
    Contact: martin.robinson@cs.ox.ac.uk
    Generated by: https://openapi-generator.tech
"""

from galv.paths.schedule_families_.post import ScheduleFamiliesCreate
from galv.paths.schedule_families_uuid_.delete import ScheduleFamiliesDestroy
from galv.paths.schedule_families_.get import ScheduleFamiliesList
from galv.paths.schedule_families_uuid_.patch import ScheduleFamiliesPartialUpdate
from galv.paths.schedule_families_uuid_.get import ScheduleFamiliesRetrieve


class ScheduleFamiliesApi(
    ScheduleFamiliesCreate,
    ScheduleFamiliesDestroy,
    ScheduleFamiliesList,
    ScheduleFamiliesPartialUpdate,
    ScheduleFamiliesRetrieve,
):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """
    pass



# coding: utf-8

"""
    Battery Data API

    A standard API for accessing battery experiment datasets and metadata  # noqa: E501

    The version of the OpenAPI document: 2.1.20
    Contact: martin.robinson@cs.ox.ac.uk
    Generated by: https://openapi-generator.tech
"""

from datetime import date, datetime  # noqa: F401
import decimal  # noqa: F401
import functools  # noqa: F401
import io  # noqa: F401
import re  # noqa: F401
import typing  # noqa: F401
import typing_extensions  # noqa: F401
import uuid  # noqa: F401

import frozendict  # noqa: F401

from galv import schemas  # noqa: F401


class SchemaValidation(
    schemas.DictSchema
):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """


    class MetaOapg:
        required = {
            "schema",
            "validation_target",
            "permissions",
            "last_update",
            "detail",
            "id",
            "url",
            "status",
        }
        
        class properties:
            url = schemas.StrSchema
            id = schemas.IntSchema
            schema = schemas.StrSchema
            validation_target = schemas.StrSchema
            
            
            class status(
                schemas.EnumBase,
                schemas.StrSchema
            ):
            
            
                class MetaOapg:
                    enum_value_to_name = {
                        "VALID": "VALID",
                        "INVALID": "INVALID",
                        "SKIPPED": "SKIPPED",
                        "UNCHECKED": "UNCHECKED",
                        "ERROR": "ERROR",
                    }
                
                @schemas.classproperty
                def VALID(cls):
                    return cls("VALID")
                
                @schemas.classproperty
                def INVALID(cls):
                    return cls("INVALID")
                
                @schemas.classproperty
                def SKIPPED(cls):
                    return cls("SKIPPED")
                
                @schemas.classproperty
                def UNCHECKED(cls):
                    return cls("UNCHECKED")
                
                @schemas.classproperty
                def ERROR(cls):
                    return cls("ERROR")
            
            
            class permissions(
                schemas.DictSchema
            ):
            
            
                class MetaOapg:
                    
                    class properties:
                        read = schemas.BoolSchema
                        write = schemas.BoolSchema
                        create = schemas.BoolSchema
                        __annotations__ = {
                            "read": read,
                            "write": write,
                            "create": create,
                        }
                
                @typing.overload
                def __getitem__(self, name: typing_extensions.Literal["read"]) -> MetaOapg.properties.read: ...
                
                @typing.overload
                def __getitem__(self, name: typing_extensions.Literal["write"]) -> MetaOapg.properties.write: ...
                
                @typing.overload
                def __getitem__(self, name: typing_extensions.Literal["create"]) -> MetaOapg.properties.create: ...
                
                @typing.overload
                def __getitem__(self, name: str) -> schemas.UnsetAnyTypeSchema: ...
                
                def __getitem__(self, name: typing.Union[typing_extensions.Literal["read", "write", "create", ], str]):
                    # dict_instance[name] accessor
                    return super().__getitem__(name)
                
                
                @typing.overload
                def get_item_oapg(self, name: typing_extensions.Literal["read"]) -> typing.Union[MetaOapg.properties.read, schemas.Unset]: ...
                
                @typing.overload
                def get_item_oapg(self, name: typing_extensions.Literal["write"]) -> typing.Union[MetaOapg.properties.write, schemas.Unset]: ...
                
                @typing.overload
                def get_item_oapg(self, name: typing_extensions.Literal["create"]) -> typing.Union[MetaOapg.properties.create, schemas.Unset]: ...
                
                @typing.overload
                def get_item_oapg(self, name: str) -> typing.Union[schemas.UnsetAnyTypeSchema, schemas.Unset]: ...
                
                def get_item_oapg(self, name: typing.Union[typing_extensions.Literal["read", "write", "create", ], str]):
                    return super().get_item_oapg(name)
                
            
                def __new__(
                    cls,
                    *_args: typing.Union[dict, frozendict.frozendict, ],
                    read: typing.Union[MetaOapg.properties.read, bool, schemas.Unset] = schemas.unset,
                    write: typing.Union[MetaOapg.properties.write, bool, schemas.Unset] = schemas.unset,
                    create: typing.Union[MetaOapg.properties.create, bool, schemas.Unset] = schemas.unset,
                    _configuration: typing.Optional[schemas.Configuration] = None,
                    **kwargs: typing.Union[schemas.AnyTypeSchema, dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, None, list, tuple, bytes],
                ) -> 'permissions':
                    return super().__new__(
                        cls,
                        *_args,
                        read=read,
                        write=write,
                        create=create,
                        _configuration=_configuration,
                        **kwargs,
                    )
            
            
            class detail(
                schemas.DictBase,
                schemas.NoneBase,
                schemas.Schema,
                schemas.NoneFrozenDictMixin
            ):
            
            
                class MetaOapg:
                    additional_properties = schemas.AnyTypeSchema
            
                
                def __getitem__(self, name: typing.Union[str, ]) -> MetaOapg.additional_properties:
                    # dict_instance[name] accessor
                    return super().__getitem__(name)
                
                def get_item_oapg(self, name: typing.Union[str, ]) -> MetaOapg.additional_properties:
                    return super().get_item_oapg(name)
            
                def __new__(
                    cls,
                    *_args: typing.Union[dict, frozendict.frozendict, None, ],
                    _configuration: typing.Optional[schemas.Configuration] = None,
                    **kwargs: typing.Union[MetaOapg.additional_properties, dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, bool, None, list, tuple, bytes, io.FileIO, io.BufferedReader, ],
                ) -> 'detail':
                    return super().__new__(
                        cls,
                        *_args,
                        _configuration=_configuration,
                        **kwargs,
                    )
            last_update = schemas.DateTimeSchema
            __annotations__ = {
                "url": url,
                "id": id,
                "schema": schema,
                "validation_target": validation_target,
                "status": status,
                "permissions": permissions,
                "detail": detail,
                "last_update": last_update,
            }
    
    schema: MetaOapg.properties.schema
    validation_target: MetaOapg.properties.validation_target
    permissions: MetaOapg.properties.permissions
    last_update: MetaOapg.properties.last_update
    detail: MetaOapg.properties.detail
    id: MetaOapg.properties.id
    url: MetaOapg.properties.url
    status: MetaOapg.properties.status
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["url"]) -> MetaOapg.properties.url: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["id"]) -> MetaOapg.properties.id: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["schema"]) -> MetaOapg.properties.schema: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["validation_target"]) -> MetaOapg.properties.validation_target: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["status"]) -> MetaOapg.properties.status: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["permissions"]) -> MetaOapg.properties.permissions: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["detail"]) -> MetaOapg.properties.detail: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["last_update"]) -> MetaOapg.properties.last_update: ...
    
    @typing.overload
    def __getitem__(self, name: str) -> schemas.UnsetAnyTypeSchema: ...
    
    def __getitem__(self, name: typing.Union[typing_extensions.Literal["url", "id", "schema", "validation_target", "status", "permissions", "detail", "last_update", ], str]):
        # dict_instance[name] accessor
        return super().__getitem__(name)
    
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["url"]) -> MetaOapg.properties.url: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["id"]) -> MetaOapg.properties.id: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["schema"]) -> MetaOapg.properties.schema: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["validation_target"]) -> MetaOapg.properties.validation_target: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["status"]) -> MetaOapg.properties.status: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["permissions"]) -> MetaOapg.properties.permissions: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["detail"]) -> MetaOapg.properties.detail: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["last_update"]) -> MetaOapg.properties.last_update: ...
    
    @typing.overload
    def get_item_oapg(self, name: str) -> typing.Union[schemas.UnsetAnyTypeSchema, schemas.Unset]: ...
    
    def get_item_oapg(self, name: typing.Union[typing_extensions.Literal["url", "id", "schema", "validation_target", "status", "permissions", "detail", "last_update", ], str]):
        return super().get_item_oapg(name)
    

    def __new__(
        cls,
        *_args: typing.Union[dict, frozendict.frozendict, ],
        schema: typing.Union[MetaOapg.properties.schema, str, ],
        validation_target: typing.Union[MetaOapg.properties.validation_target, str, ],
        permissions: typing.Union[MetaOapg.properties.permissions, dict, frozendict.frozendict, ],
        last_update: typing.Union[MetaOapg.properties.last_update, str, datetime, ],
        detail: typing.Union[MetaOapg.properties.detail, dict, frozendict.frozendict, None, ],
        id: typing.Union[MetaOapg.properties.id, decimal.Decimal, int, ],
        url: typing.Union[MetaOapg.properties.url, str, ],
        status: typing.Union[MetaOapg.properties.status, str, ],
        _configuration: typing.Optional[schemas.Configuration] = None,
        **kwargs: typing.Union[schemas.AnyTypeSchema, dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, None, list, tuple, bytes],
    ) -> 'SchemaValidation':
        return super().__new__(
            cls,
            *_args,
            schema=schema,
            validation_target=validation_target,
            permissions=permissions,
            last_update=last_update,
            detail=detail,
            id=id,
            url=url,
            status=status,
            _configuration=_configuration,
            **kwargs,
        )



from galv.paths.validation_schemas_uuid_.get import ApiForget
from galv.paths.validation_schemas_uuid_.put import ApiForput
from galv.paths.validation_schemas_uuid_.delete import ApiFordelete
from galv.paths.validation_schemas_uuid_.patch import ApiForpatch


class ValidationSchemasUuid(
    ApiForget,
    ApiForput,
    ApiFordelete,
    ApiForpatch,
):
    pass



from galv.paths.monitored_paths_uuid_.get import ApiForget
from galv.paths.monitored_paths_uuid_.delete import ApiFordelete
from galv.paths.monitored_paths_uuid_.patch import ApiForpatch


class MonitoredPathsUuid(
    ApiForget,
    ApiFordelete,
    ApiForpatch,
):
    pass



# coding: utf-8

"""
    Battery Data API

    A standard API for accessing battery experiment datasets and metadata  # noqa: E501

    The version of the OpenAPI document: 2.1.20
    Contact: martin.robinson@cs.ox.ac.uk
    Generated by: https://openapi-generator.tech
"""

from datetime import date, datetime  # noqa: F401
import decimal  # noqa: F401
import functools  # noqa: F401
import io  # noqa: F401
import re  # noqa: F401
import typing  # noqa: F401
import typing_extensions  # noqa: F401
import uuid  # noqa: F401

import frozendict  # noqa: F401

from galv import schemas  # noqa: F401


class PatchedHarvesterRequest(
    schemas.DictSchema
):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """


    class MetaOapg:
        
        class properties:
            
            
            class name(
                schemas.StrSchema
            ):
            
            
                class MetaOapg:
                    min_length = 1
            
            
            class sleep_time(
                schemas.IntSchema
            ):
            
            
                class MetaOapg:
                    inclusive_maximum = 2147483647
                    inclusive_minimum = -2147483648
            
            
            class environment_variables(
                schemas.DictSchema
            ):
            
            
                class MetaOapg:
                    additional_properties = schemas.AnyTypeSchema
                
                def __getitem__(self, name: typing.Union[str, ]) -> MetaOapg.additional_properties:
                    # dict_instance[name] accessor
                    return super().__getitem__(name)
                
                def get_item_oapg(self, name: typing.Union[str, ]) -> MetaOapg.additional_properties:
                    return super().get_item_oapg(name)
            
                def __new__(
                    cls,
                    *_args: typing.Union[dict, frozendict.frozendict, ],
                    _configuration: typing.Optional[schemas.Configuration] = None,
                    **kwargs: typing.Union[MetaOapg.additional_properties, dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, bool, None, list, tuple, bytes, io.FileIO, io.BufferedReader, ],
                ) -> 'environment_variables':
                    return super().__new__(
                        cls,
                        *_args,
                        _configuration=_configuration,
                        **kwargs,
                    )
            active = schemas.BoolSchema
            __annotations__ = {
                "name": name,
                "sleep_time": sleep_time,
                "environment_variables": environment_variables,
                "active": active,
            }
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["name"]) -> MetaOapg.properties.name: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["sleep_time"]) -> MetaOapg.properties.sleep_time: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["environment_variables"]) -> MetaOapg.properties.environment_variables: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["active"]) -> MetaOapg.properties.active: ...
    
    @typing.overload
    def __getitem__(self, name: str) -> schemas.UnsetAnyTypeSchema: ...
    
    def __getitem__(self, name: typing.Union[typing_extensions.Literal["name", "sleep_time", "environment_variables", "active", ], str]):
        # dict_instance[name] accessor
        return super().__getitem__(name)
    
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["name"]) -> typing.Union[MetaOapg.properties.name, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["sleep_time"]) -> typing.Union[MetaOapg.properties.sleep_time, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["environment_variables"]) -> typing.Union[MetaOapg.properties.environment_variables, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["active"]) -> typing.Union[MetaOapg.properties.active, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: str) -> typing.Union[schemas.UnsetAnyTypeSchema, schemas.Unset]: ...
    
    def get_item_oapg(self, name: typing.Union[typing_extensions.Literal["name", "sleep_time", "environment_variables", "active", ], str]):
        return super().get_item_oapg(name)
    

    def __new__(
        cls,
        *_args: typing.Union[dict, frozendict.frozendict, ],
        name: typing.Union[MetaOapg.properties.name, str, schemas.Unset] = schemas.unset,
        sleep_time: typing.Union[MetaOapg.properties.sleep_time, decimal.Decimal, int, schemas.Unset] = schemas.unset,
        environment_variables: typing.Union[MetaOapg.properties.environment_variables, dict, frozendict.frozendict, schemas.Unset] = schemas.unset,
        active: typing.Union[MetaOapg.properties.active, bool, schemas.Unset] = schemas.unset,
        _configuration: typing.Optional[schemas.Configuration] = None,
        **kwargs: typing.Union[schemas.AnyTypeSchema, dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, None, list, tuple, bytes],
    ) -> 'PatchedHarvesterRequest':
        return super().__new__(
            cls,
            *_args,
            name=name,
            sleep_time=sleep_time,
            environment_variables=environment_variables,
            active=active,
            _configuration=_configuration,
            **kwargs,
        )



# coding: utf-8

"""
    Battery Data API

    A standard API for accessing battery experiment datasets and metadata  # noqa: E501

    The version of the OpenAPI document: 2.1.20
    Contact: martin.robinson@cs.ox.ac.uk
    Generated by: https://openapi-generator.tech
"""

from datetime import date, datetime  # noqa: F401
import decimal  # noqa: F401
import functools  # noqa: F401
import io  # noqa: F401
import re  # noqa: F401
import typing  # noqa: F401
import typing_extensions  # noqa: F401
import uuid  # noqa: F401

import frozendict  # noqa: F401

from galv import schemas  # noqa: F401


class PermittedAccessLevels(
    schemas.DictSchema
):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """


    class MetaOapg:
        required = {
            "delete_access_level",
            "path.edit_access_level",
            "edit_access_level",
            "read_access_level",
        }
        
        class properties:
            
            
            class read_access_level(
                schemas.DictSchema
            ):
            
            
                class MetaOapg:
                    additional_properties = schemas.IntSchema
                
                def __getitem__(self, name: typing.Union[str, ]) -> MetaOapg.additional_properties:
                    # dict_instance[name] accessor
                    return super().__getitem__(name)
                
                def get_item_oapg(self, name: typing.Union[str, ]) -> MetaOapg.additional_properties:
                    return super().get_item_oapg(name)
            
                def __new__(
                    cls,
                    *_args: typing.Union[dict, frozendict.frozendict, ],
                    _configuration: typing.Optional[schemas.Configuration] = None,
                    **kwargs: typing.Union[MetaOapg.additional_properties, decimal.Decimal, int, ],
                ) -> 'read_access_level':
                    return super().__new__(
                        cls,
                        *_args,
                        _configuration=_configuration,
                        **kwargs,
                    )
            
            
            class edit_access_level(
                schemas.DictSchema
            ):
            
            
                class MetaOapg:
                    additional_properties = schemas.IntSchema
                
                def __getitem__(self, name: typing.Union[str, ]) -> MetaOapg.additional_properties:
                    # dict_instance[name] accessor
                    return super().__getitem__(name)
                
                def get_item_oapg(self, name: typing.Union[str, ]) -> MetaOapg.additional_properties:
                    return super().get_item_oapg(name)
            
                def __new__(
                    cls,
                    *_args: typing.Union[dict, frozendict.frozendict, ],
                    _configuration: typing.Optional[schemas.Configuration] = None,
                    **kwargs: typing.Union[MetaOapg.additional_properties, decimal.Decimal, int, ],
                ) -> 'edit_access_level':
                    return super().__new__(
                        cls,
                        *_args,
                        _configuration=_configuration,
                        **kwargs,
                    )
            
            
            class delete_access_level(
                schemas.DictSchema
            ):
            
            
                class MetaOapg:
                    additional_properties = schemas.IntSchema
                
                def __getitem__(self, name: typing.Union[str, ]) -> MetaOapg.additional_properties:
                    # dict_instance[name] accessor
                    return super().__getitem__(name)
                
                def get_item_oapg(self, name: typing.Union[str, ]) -> MetaOapg.additional_properties:
                    return super().get_item_oapg(name)
            
                def __new__(
                    cls,
                    *_args: typing.Union[dict, frozendict.frozendict, ],
                    _configuration: typing.Optional[schemas.Configuration] = None,
                    **kwargs: typing.Union[MetaOapg.additional_properties, decimal.Decimal, int, ],
                ) -> 'delete_access_level':
                    return super().__new__(
                        cls,
                        *_args,
                        _configuration=_configuration,
                        **kwargs,
                    )
            
            
            class path_edit_access_level(
                schemas.DictSchema
            ):
            
            
                class MetaOapg:
                    additional_properties = schemas.IntSchema
                
                def __getitem__(self, name: typing.Union[str, ]) -> MetaOapg.additional_properties:
                    # dict_instance[name] accessor
                    return super().__getitem__(name)
                
                def get_item_oapg(self, name: typing.Union[str, ]) -> MetaOapg.additional_properties:
                    return super().get_item_oapg(name)
            
                def __new__(
                    cls,
                    *_args: typing.Union[dict, frozendict.frozendict, ],
                    _configuration: typing.Optional[schemas.Configuration] = None,
                    **kwargs: typing.Union[MetaOapg.additional_properties, decimal.Decimal, int, ],
                ) -> 'path_edit_access_level':
                    return super().__new__(
                        cls,
                        *_args,
                        _configuration=_configuration,
                        **kwargs,
                    )
            __annotations__ = {
                "read_access_level": read_access_level,
                "edit_access_level": edit_access_level,
                "delete_access_level": delete_access_level,
                "path.edit_access_level": path_edit_access_level,
            }
    
    delete_access_level: MetaOapg.properties.delete_access_level
    edit_access_level: MetaOapg.properties.edit_access_level
    read_access_level: MetaOapg.properties.read_access_level
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["read_access_level"]) -> MetaOapg.properties.read_access_level: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["edit_access_level"]) -> MetaOapg.properties.edit_access_level: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["delete_access_level"]) -> MetaOapg.properties.delete_access_level: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["path.edit_access_level"]) -> MetaOapg.properties.path_edit_access_level: ...
    
    @typing.overload
    def __getitem__(self, name: str) -> schemas.UnsetAnyTypeSchema: ...
    
    def __getitem__(self, name: typing.Union[typing_extensions.Literal["read_access_level", "edit_access_level", "delete_access_level", "path.edit_access_level", ], str]):
        # dict_instance[name] accessor
        return super().__getitem__(name)
    
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["read_access_level"]) -> MetaOapg.properties.read_access_level: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["edit_access_level"]) -> MetaOapg.properties.edit_access_level: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["delete_access_level"]) -> MetaOapg.properties.delete_access_level: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["path.edit_access_level"]) -> MetaOapg.properties.path_edit_access_level: ...
    
    @typing.overload
    def get_item_oapg(self, name: str) -> typing.Union[schemas.UnsetAnyTypeSchema, schemas.Unset]: ...
    
    def get_item_oapg(self, name: typing.Union[typing_extensions.Literal["read_access_level", "edit_access_level", "delete_access_level", "path.edit_access_level", ], str]):
        return super().get_item_oapg(name)
    

    def __new__(
        cls,
        *_args: typing.Union[dict, frozendict.frozendict, ],
        delete_access_level: typing.Union[MetaOapg.properties.delete_access_level, dict, frozendict.frozendict, ],
        edit_access_level: typing.Union[MetaOapg.properties.edit_access_level, dict, frozendict.frozendict, ],
        read_access_level: typing.Union[MetaOapg.properties.read_access_level, dict, frozendict.frozendict, ],
        _configuration: typing.Optional[schemas.Configuration] = None,
        **kwargs: typing.Union[schemas.AnyTypeSchema, dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, None, list, tuple, bytes],
    ) -> 'PermittedAccessLevels':
        return super().__new__(
            cls,
            *_args,
            delete_access_level=delete_access_level,
            edit_access_level=edit_access_level,
            read_access_level=read_access_level,
            _configuration=_configuration,
            **kwargs,
        )



from galv.paths.schedules_uuid_.get import ApiForget
from galv.paths.schedules_uuid_.delete import ApiFordelete
from galv.paths.schedules_uuid_.patch import ApiForpatch


class SchedulesUuid(
    ApiForget,
    ApiFordelete,
    ApiForpatch,
):
    pass



# do not import all endpoints into this module because that uses a lot of memory and stack frames
# if you need the ability to import all endpoints from this module, import them with
# from galv.apis.path_to_api import path_to_api

import enum


class PathValues(str, enum.Enum):
    ACCESS_LEVELS_ = "/access_levels/"
    ACTIVATE_ = "/activate/"
    ARBITRARY_FILES_ = "/arbitrary_files/"
    ARBITRARY_FILES_UUID_ = "/arbitrary_files/{uuid}/"
    CELL_CHEMISTRIES_ = "/cell_chemistries/"
    CELL_FAMILIES_ = "/cell_families/"
    CELL_FAMILIES_UUID_ = "/cell_families/{uuid}/"
    CELL_FORM_FACTORS_ = "/cell_form_factors/"
    CELL_MANUFACTURERS_ = "/cell_manufacturers/"
    CELL_MODELS_ = "/cell_models/"
    CELLS_ = "/cells/"
    CELLS_UUID_ = "/cells/{uuid}/"
    CELLS_UUID_RDF_ = "/cells/{uuid}/rdf/"
    COLUMN_TYPES_ = "/column_types/"
    COLUMN_TYPES_ID_ = "/column_types/{id}/"
    COLUMNS_ = "/columns/"
    COLUMNS_ID_ = "/columns/{id}/"
    COLUMNS_ID_VALUES_ = "/columns/{id}/values/"
    CREATE_TOKEN_ = "/create_token/"
    CYCLER_TESTS_ = "/cycler_tests/"
    CYCLER_TESTS_UUID_ = "/cycler_tests/{uuid}/"
    EQUIPMENT_ = "/equipment/"
    EQUIPMENT_UUID_ = "/equipment/{uuid}/"
    EQUIPMENT_FAMILIES_ = "/equipment_families/"
    EQUIPMENT_FAMILIES_UUID_ = "/equipment_families/{uuid}/"
    EQUIPMENT_MANUFACTURERS_ = "/equipment_manufacturers/"
    EQUIPMENT_MODELS_ = "/equipment_models/"
    EQUIPMENT_TYPES_ = "/equipment_types/"
    EXPERIMENTS_ = "/experiments/"
    EXPERIMENTS_UUID_ = "/experiments/{uuid}/"
    FILES_ = "/files/"
    FILES_UUID_ = "/files/{uuid}/"
    FILES_UUID_REIMPORT_ = "/files/{uuid}/reimport/"
    HARVEST_ERRORS_ = "/harvest_errors/"
    HARVEST_ERRORS_ID_ = "/harvest_errors/{id}/"
    HARVESTERS_ = "/harvesters/"
    HARVESTERS_UUID_ = "/harvesters/{uuid}/"
    LABS_ = "/labs/"
    LABS_ID_ = "/labs/{id}/"
    LOGIN_ = "/login/"
    MONITORED_PATHS_ = "/monitored_paths/"
    MONITORED_PATHS_UUID_ = "/monitored_paths/{uuid}/"
    SCHEDULE_FAMILIES_ = "/schedule_families/"
    SCHEDULE_FAMILIES_UUID_ = "/schedule_families/{uuid}/"
    SCHEDULE_IDENTIFIERS_ = "/schedule_identifiers/"
    SCHEDULES_ = "/schedules/"
    SCHEDULES_UUID_ = "/schedules/{uuid}/"
    SCHEMA_VALIDATIONS_ = "/schema_validations/"
    SCHEMA_VALIDATIONS_ID_ = "/schema_validations/{id}/"
    TEAMS_ = "/teams/"
    TEAMS_ID_ = "/teams/{id}/"
    TOKENS_ = "/tokens/"
    TOKENS_ID_ = "/tokens/{id}/"
    UNITS_ = "/units/"
    UNITS_ID_ = "/units/{id}/"
    USERS_ = "/users/"
    USERS_ID_ = "/users/{id}/"
    VALIDATION_SCHEMAS_ = "/validation_schemas/"
    VALIDATION_SCHEMAS_UUID_ = "/validation_schemas/{uuid}/"
    VALIDATION_SCHEMAS_KEYS_ = "/validation_schemas/keys/"
